import React, {memo} from 'react';
import {Image, TouchableOpacity, View} from 'react-native';
import AppText from '../../../../components/AppText';
import {IMAGES} from '../../../../values/images';
import string from '../../../../values/string';
import styles from '../../style';
import commonStyles from '../../../../styles/commonStyles';

const PersonalInformation = React.memo(
  ({userInfo}) => {
    const personalInfo = [
      {
        name: 'Họ',
        value: userInfo?.first_name || '',
        icon: IMAGES.IcInfoGuess,
        width: '50%',
      },
      {
        name: 'Tên lót',
        value: userInfo?.middle_name || '',
        icon: IMAGES.IcInfoGuess,
        width: '50%',
      },
      {
        name: 'Tên',
        value: userInfo?.last_name || '',
        icon: IMAGES.IcInfoGuess,
        width: '50%',
      },
      {
        name: 'Giới tính',
        value: userInfo?.gender ? 'Nam' : 'Nữ',
        icon: IMAGES.IcInfoGuess,
        width: '50%',
      },
      {
        name: 'Số điện thoại',
        value: userInfo?.cell_phone || '',
        icon: IMAGES.IcPhone,
        width: '100%',
      },
      {
        name: 'Email',
        value: userInfo?.email || '',
        icon: IMAGES.IcMailGray,
        width: '100%',
      },
    ];
    return (
      <View style={[styles.viewInfo]}>
        <View style={styles.viewTitle}>
          <AppText style={{fontSize: 17}}>
            {string.PERSONAL_INFORMATION}
          </AppText>
          <View>
            <TouchableOpacity>
              <Image source={IMAGES.IcEdit} style={{height: 30, width: 30}} />
            </TouchableOpacity>
          </View>
        </View>
        <View style={[commonStyles.row, {flexWrap: 'wrap'}]}>
          {personalInfo.map(item => (
            <View
              key={item.name}
              style={[styles.infoView, {width: item.width}]}>
              <Image source={item.icon} style={{width: 20, height: 20}} />
              <View style={{marginLeft: 5}}>
                <AppText>{item.name}</AppText>
                <AppText isSubText>{item?.value}</AppText>
              </View>
            </View>
          ))}
        </View>
      </View>
    );
  },
  function (prevProps, nextProps) {
    return prevProps.userInfo === nextProps.userInfo;
  },
);

export default memo(PersonalInformation);
